Package 'rversions'

Title: Query 'R' Versions, Including 'r-release' and 'r-oldrel'
Description: Query the main 'R' 'SVN' repository to find the versions 'r-release' and 'r-oldrel' refer to, and also all previous 'R' versions and their release dates.
Authors: Gábor Csárdi [aut, cre], Jeroen Ooms [ctb], R Consortium [fnd], Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Gábor Csárdi <[email protected]>
License: MIT + file LICENSE
Version: 3.0.0.9000
Built: 2026-05-20 08:38:08 UTC
Source: https://github.com/r-hub/rversions

Help Index


Available R Builds

Description

Available R Builds

Usage

available(platform = current_r_platform())

Arguments

platform

Operating system version. Defaults to current_r_platform(). Possible values are:

  • windows: x86_64 Windows.

  • windows-x86_64: the same.

  • windows-aarch64: aarch64 Windows.

  • macos: arm64 macOS.

  • macos-arm64: the same.

  • macos-x86_64: x86_64 macOS.

  • ⁠linux-<distro>-<release>⁠: x86_64 Linux on the given distribution and release, e.g. linux-ubuntu-22.04.

  • A target triplet of the form cpu-vendor-os-abi. On Linux it should also include the distribution name and release. See current_r_platform() for examples.

Details

available() caches its results in the current R session. To clear the cache restart R or set the R_VERSION_CACHE_TIMEOUT environment variable to 0.

Value

A data frame with columns version, date, semver, type, and url.

Examples

available()
available("windows")
available("macos-arm64")
available("linux-gnu-ubuntu-24.04")
available("aarch64-unknown-linux-gnu-ubuntu-22.04")

Current R platform

Description

current_r_platform() detects the platform of the current R version.

Usage

current_r_platform()

Details

It returns a string of the form cpu-vendor-os-abi, a target triplet, see some examples below. On Linux it also includes the distribution name and version and part of the ABI.

Examples:

  • x86_64-apple-darwin17.0: macOS High Sierra.

  • aarch64-apple-darwin20: macOS Big Sur on arm64.

  • x86_64-w64-mingw32: 64 bit Windows.

  • i386-w64-mingw32: 32 bit Windows.

  • i386+x86_64-w64-mingw32: 64 bit + 32 bit Windows.

  • i386-pc-solaris2.10: 32 bit Solaris. (Some broken 64 Solaris builds might have the same platform string, unfortunately.)

  • x86_64-pc-linux-gnu-debian-10: Debian Linux 10 on x86_64.

  • ⁠x86_64-pc-linux-musl-alpine-3.14.1⁠: Alpine Linux.

  • x86_64-pc-linux-gnu-unknown: Unknown Linux Distribution on x86_64.

  • s390x-ibm-linux-gnu-ubuntu-20.04: Ubuntu Linux 20.04 on S390x.

  • amd64-portbld-freebsd12.1: FreeBSD 12.1 on x86_64.

Examples

current_r_platform()

Return information about Posit's (and some other) R builds for Linux

Description

Return information about Posit's (and some other) R builds for Linux

Usage

linux_distros()

Details

linux_distros() caches its results in the current R session. To clear the cache restart R or set the R_VERSION_CACHE_TIMEOUT environment variable to 0.

Value

A data frame with the following columns:

  • id: The distro ID, e.g. ubuntu-2404.

  • aliases: A list column of character vectors with alternative names for the distro. Alternative names starting and ending with a forward slash are regular expressions.

  • name: The full name of the distro, e.g. ⁠Red Hat Enterprise Linux⁠.

  • version: The version of the distro, e.g. 24.04 for Ubuntu, or 9 for RHEL.

  • codename: The codename of the distro, e.g. focal for Ubuntu 20.04.

  • url: The URL of the distro's homepage.

  • docker: The name of the official Docker image for the distro, e.g. ubuntu:20.04.

  • eol: The end-of-life date of the distro, or NA if unknown.

  • retired: whether the distro version is retired for Posit and R-hub.

  • aarch64: whether aarch64 builds are available for this distro. Possible values are posit (builds are available from Posit), r-hub (builds are available from R-hub), none (no builds are available).

  • ppm_binaries: whether PPM binaries are available for this distro.

  • ppm_aarch64: whether aarch64 PPM binaries are available for this distro.

  • ppm_url: The URL of the PPM binaries for this distro.

Examples

linux_distros()

Version number of R-oldrel

Description

R-oldrel is the latest version of the previous minor version. We extract version numbers from the R SVN repository tags.

Usage

r_oldrel(dots = TRUE)

Arguments

dots

Whether to use dots instead of dashes in the version number.

Value

A one row data frame, with columns ‘version’, ‘date’ and ‘nickname’.

Note

This function is superseded by resolve():

r_oldrel()
#> # A data frame: 1 x 5
#>   version date                nickname    semver     URL                        
#>   <chr>   <dttm>              <chr>       <pckg_vrs> <chr>                      
#> 1 4.4.3   2025-02-28 08:08:59 Trophy Case 4.4.3      https://cran.rstudio.com/s~
resolve("oldrel", platform = NA)
#> # A data frame: 1 x 6
#>   version date                nickname    semver     url                   type 
#>   <chr>   <dttm>              <chr>       <pckg_vrs> <chr>                 <chr>
#> 1 4.4.3   2025-02-28 08:08:59 Trophy Case 4.4.3      https://cran.rstudio~ oldr~

Examples

r_oldrel()

Version number of R-release

Description

The latest tag in the SVN repository (in terms of version numbers, not dates).

Usage

r_release(dots = TRUE)

Arguments

dots

Whether to use dots instead of dashes in the version number.

Value

A one row data frame, with columns ‘version’, ‘date’ and ‘nickname’.

Note

This function is superseded by resolve():

r_release()
#> # A data frame: 1 x 6
#>   version date                nickname          semver     URL             type 
#>   <chr>   <dttm>              <chr>             <pckg_vrs> <chr>           <chr>
#> 1 4.5.1   2025-06-13 07:12:01 Great Square Root 4.5.1      https://cran.r~ rele~
resolve("release", platform = NA)
#> # A data frame: 1 x 6
#>   version date                nickname          semver     url             type 
#>   <chr>   <dttm>              <chr>             <pckg_vrs> <chr>           <chr>
#> 1 4.5.1   2025-06-13 07:12:01 Great Square Root 4.5.1      https://cran.r~ rele~

Examples

r_release()

Latest R release with a macOS installer available for download

Description

r_release() works based on the SVN tags in the main R source code repository. However, an SVN tag does not mean that the same version is available for download. r_release_macos returns the latest version for which a macOS installer is available.

Usage

r_release_macos(arch = c("x86_64", "arm64"))

Arguments

arch

The architecture, either ‘x86_64’ or ‘arm64’.

Value

A one row data frame, with columns ‘version’, ‘date’, ‘URL’ and ‘nickname’.

Note

This function is superseded by resolve():

r_release_macos()
#> # A data frame: 1 x 5
#>   version date                nickname          semver     URL                  
#>   <chr>   <dttm>              <chr>             <pckg_vrs> <chr>                
#> 1 4.5.1   2025-06-13 07:12:01 Great Square Root 4.5.1      https://cran.rstudio~
resolve("release", platform = "macos")
#> # A data frame: 1 x 6
#>   version date                nickname          semver     url             type 
#>   <chr>   <dttm>              <chr>             <pckg_vrs> <chr>           <chr>
#> 1 4.5.1   2025-06-13 07:12:01 Great Square Root 4.5.1      https://cran.r~ rele~

See Also

Other R downloads: r_release_tarball(), r_release_win()

Examples

r_release()
r_release_macos()
r_release_macos(arch = "arm64")

Latest release for which a source tarball is available for download

Description

r_release() works based on the SVN tags in the main R source code repository. However, an SVN tag does not mean that the same version is available for download. r_release_tarball returns the latest version for which a source tarball is available.

Usage

r_release_tarball()

Value

A one row data frame, with columns ‘version’, ‘date’, ‘URL’ and ‘nickname’.

Note

This function is superseded by resolve():

r_release_tarball()
#> # A data frame: 1 x 5
#>   version date                nickname          semver     URL                  
#>   <chr>   <dttm>              <chr>             <pckg_vrs> <chr>                
#> 1 4.5.1   2025-06-13 07:12:01 Great Square Root 4.5.1      https://cran.rstudio~
resolve("release", platform = NA)
#> # A data frame: 1 x 6
#>   version date                nickname          semver     url             type 
#>   <chr>   <dttm>              <chr>             <pckg_vrs> <chr>           <chr>
#> 1 4.5.1   2025-06-13 07:12:01 Great Square Root 4.5.1      https://cran.r~ rele~

See Also

Other R downloads: r_release_macos(), r_release_win()

Examples

r_release()
r_release_tarball()

Latest R release with a Windows installer available for download

Description

r_release() works based on the SVN tags in the main R source code repository. However, an SVN tag does not mean that the same version is available for download. r_release_win returns the latest version for which a Windows installer is available.

Usage

r_release_win()

Value

A one row data frame, with columns ‘version’, ‘date’, ‘URL’ and ‘nickname’.

Note

This function is superseded by resolve():

r_release_win()
#> # A data frame: 1 x 5
#>   version date                nickname          semver     URL                  
#>   <chr>   <dttm>              <chr>             <pckg_vrs> <chr>                
#> 1 4.5.1   2025-06-13 07:12:01 Great Square Root 4.5.1      https://cran.rstudio~
resolve("release", platform = "windows")
#> # A data frame: 1 x 7
#>   version date                nickname          semver    url   type  rtools_url
#>   <chr>   <dttm>              <chr>             <pckg_vr> <chr> <chr> <chr>     
#> 1 4.5.1   2025-06-13 07:12:01 Great Square Root 4.5.1     http~ rele~ https://g~

See Also

Other R downloads: r_release_macos(), r_release_tarball()

Examples

r_release()
r_release_win()

Query R's past and present versions

Description

R version numbers consist of three numbers (since version 1.4.1): major, minor and patch.

Usage

r_versions(dots = TRUE)

Arguments

dots

Whether to use dots instead of dashes in the version number.

Details

We extract the version numbers from the tags in the SVN repository.

Value

A data frame with three columns: ‘version’, ‘date’ and ‘nickname’.

Examples

r_versions()

Resolve an R version specification

Description

Resolve an R version specification

Usage

resolve(version = "release", platform = current_r_platform())

Arguments

version

Symbolic version name to resolve. Possible values are

  • release: the latest release version,

  • devel: Development version of R.

  • next: The next version of R. This is R-patched if there is no ongoing release process currently. Otherwise it may be R-alpha, R-beta, or R-rc or R-prerelease.

  • oldrel: The previous version of R, not counting patch versions.

  • ⁠oldrel/<n>⁠: The n-th previous version of R, not counting patch versions.

  • x.y.z: A specific R version, e.g. 4.5.1.

  • x.y: The last patch release from a minor R branch, e.g. 4.4.

platform

Operating system version. Defaults to current_r_platform(). Possible values are:

  • NA: to get information about platform-independent release archives.

  • windows: x86_64 Windows.

  • windows-x86_64: the same.

  • windows-aarch64: aarch64 Windows.

  • macos: arm64 macOS.

  • macos-arm64: the same.

  • macos-x86_64: x86_64 macOS.

  • ⁠linux-<distro>-<release>⁠: x86_64 Linux on the given distribution and release, e.g. linux-ubuntu-22.04.

  • A target triplet of the form cpu-vendor-os-abi. On Linux it should also include the distribution name and release. See current_r_platform() for examples.

Details

resolve() caches its results in the current R session. To clear the cache restart R or set the R_VERSION_CACHE_TIMEOUT environment variable to 0.

Value

A one row data frame, with columns version, date, nickname, semver, url, type, rtools_url (only for Windows).

Examples

resolve("release", "windows")
resolve("4.4", "windows-aarch64")
resolve("oldrel", "macos")
resolve("devel", "linux-gnu-ubuntu-24.04")
resolve("devel", "aarch64-unknown-linux-gnu-ubuntu-22.04")

List Rtools versions

Description

List Rtools versions

Usage

rtools_versions(arch = NULL)

Arguments

arch

Architecture. Possible values are:

  • x86_64: x86_64 Windows,

  • aarch64 or arm64: aarch64 Windows. Defaults tp the current architecture on Windows, and to x86_64 on other systems.

Value

A data frame with columns

  • version: The Rtools version, e.g. 45.

  • url: Download URL of the Rtools installer.

  • first: First R version supported by this Rtools version.

  • last: Last R version supported by this Rtools version.

Examples

rtools_versions()
rtools_versions("aarch64")