| Title: | Query 'R' Versions, Including 'r-release' and 'r-oldrel' |
|---|---|
| Description: | Query the main 'R' 'SVN' repository to find the versions 'r-release' and 'r-oldrel' refer to, and also all previous 'R' versions and their release dates. |
| Authors: | Gábor Csárdi [aut, cre], Jeroen Ooms [ctb], R Consortium [fnd], Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>) |
| Maintainer: | Gábor Csárdi <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 3.0.0.9000 |
| Built: | 2026-05-20 08:38:08 UTC |
| Source: | https://github.com/r-hub/rversions |
Available R Builds
available(platform = current_r_platform())available(platform = current_r_platform())
platform |
Operating system version. Defaults to
|
available() caches its results in the current R session. To clear the
cache restart R or set the R_VERSION_CACHE_TIMEOUT environment
variable to 0.
A data frame with columns version, date, semver, type,
and url.
available() available("windows") available("macos-arm64") available("linux-gnu-ubuntu-24.04") available("aarch64-unknown-linux-gnu-ubuntu-22.04")available() available("windows") available("macos-arm64") available("linux-gnu-ubuntu-24.04") available("aarch64-unknown-linux-gnu-ubuntu-22.04")
current_r_platform() detects the platform of the current R version.
current_r_platform()current_r_platform()
It returns a string of the form cpu-vendor-os-abi, a target triplet,
see some examples below. On Linux it also includes the distribution
name and version and part of the ABI.
Examples:
x86_64-apple-darwin17.0: macOS High Sierra.
aarch64-apple-darwin20: macOS Big Sur on arm64.
x86_64-w64-mingw32: 64 bit Windows.
i386-w64-mingw32: 32 bit Windows.
i386+x86_64-w64-mingw32: 64 bit + 32 bit Windows.
i386-pc-solaris2.10: 32 bit Solaris. (Some broken 64 Solaris
builds might have the same platform string, unfortunately.)
x86_64-pc-linux-gnu-debian-10: Debian Linux 10 on x86_64.
x86_64-pc-linux-musl-alpine-3.14.1: Alpine Linux.
x86_64-pc-linux-gnu-unknown: Unknown Linux Distribution on x86_64.
s390x-ibm-linux-gnu-ubuntu-20.04: Ubuntu Linux 20.04 on S390x.
amd64-portbld-freebsd12.1: FreeBSD 12.1 on x86_64.
current_r_platform()current_r_platform()
Return information about Posit's (and some other) R builds for Linux
linux_distros()linux_distros()
linux_distros() caches its results in the current R session. To clear
the cache restart R or set the R_VERSION_CACHE_TIMEOUT environment
variable to 0.
A data frame with the following columns:
id: The distro ID, e.g. ubuntu-2404.
aliases: A list column of character vectors with alternative names
for the distro. Alternative names starting and ending with a forward
slash are regular expressions.
name: The full name of the distro, e.g. Red Hat Enterprise Linux.
version: The version of the distro, e.g. 24.04 for Ubuntu, or 9
for RHEL.
codename: The codename of the distro, e.g. focal for Ubuntu 20.04.
url: The URL of the distro's homepage.
docker: The name of the official Docker image for the distro,
e.g. ubuntu:20.04.
eol: The end-of-life date of the distro, or NA if unknown.
retired: whether the distro version is retired for Posit and R-hub.
aarch64: whether aarch64 builds are available for this distro.
Possible values are posit (builds are available from Posit),
r-hub (builds are available from R-hub), none (no builds are
available).
ppm_binaries: whether PPM binaries are available for this distro.
ppm_aarch64: whether aarch64 PPM binaries are available for this
distro.
ppm_url: The URL of the PPM binaries for this distro.
linux_distros()linux_distros()
R-oldrel is the latest version of the previous minor version. We extract version numbers from the R SVN repository tags.
r_oldrel(dots = TRUE)r_oldrel(dots = TRUE)
dots |
Whether to use dots instead of dashes in the version number. |
A one row data frame, with columns ‘version’, ‘date’ and ‘nickname’.
This function is superseded by resolve():
r_oldrel() #> # A data frame: 1 x 5 #> version date nickname semver URL #> <chr> <dttm> <chr> <pckg_vrs> <chr> #> 1 4.4.3 2025-02-28 08:08:59 Trophy Case 4.4.3 https://cran.rstudio.com/s~
resolve("oldrel", platform = NA)
#> # A data frame: 1 x 6
#> version date nickname semver url type
#> <chr> <dttm> <chr> <pckg_vrs> <chr> <chr>
#> 1 4.4.3 2025-02-28 08:08:59 Trophy Case 4.4.3 https://cran.rstudio~ oldr~
r_oldrel()r_oldrel()
The latest tag in the SVN repository (in terms of version numbers, not dates).
r_release(dots = TRUE)r_release(dots = TRUE)
dots |
Whether to use dots instead of dashes in the version number. |
A one row data frame, with columns ‘version’, ‘date’ and ‘nickname’.
This function is superseded by resolve():
r_release() #> # A data frame: 1 x 6 #> version date nickname semver URL type #> <chr> <dttm> <chr> <pckg_vrs> <chr> <chr> #> 1 4.5.1 2025-06-13 07:12:01 Great Square Root 4.5.1 https://cran.r~ rele~
resolve("release", platform = NA)
#> # A data frame: 1 x 6
#> version date nickname semver url type
#> <chr> <dttm> <chr> <pckg_vrs> <chr> <chr>
#> 1 4.5.1 2025-06-13 07:12:01 Great Square Root 4.5.1 https://cran.r~ rele~
r_release()r_release()
r_release() works based on the SVN tags in the main R source code
repository. However, an SVN tag does not mean that the same version
is available for download. r_release_macos returns the latest
version for which a macOS installer is available.
r_release_macos(arch = c("x86_64", "arm64"))r_release_macos(arch = c("x86_64", "arm64"))
arch |
The architecture, either ‘x86_64’ or ‘arm64’. |
A one row data frame, with columns ‘version’, ‘date’, ‘URL’ and ‘nickname’.
This function is superseded by resolve():
r_release_macos() #> # A data frame: 1 x 5 #> version date nickname semver URL #> <chr> <dttm> <chr> <pckg_vrs> <chr> #> 1 4.5.1 2025-06-13 07:12:01 Great Square Root 4.5.1 https://cran.rstudio~
resolve("release", platform = "macos")
#> # A data frame: 1 x 6
#> version date nickname semver url type
#> <chr> <dttm> <chr> <pckg_vrs> <chr> <chr>
#> 1 4.5.1 2025-06-13 07:12:01 Great Square Root 4.5.1 https://cran.r~ rele~
Other R downloads:
r_release_tarball(),
r_release_win()
r_release() r_release_macos() r_release_macos(arch = "arm64")r_release() r_release_macos() r_release_macos(arch = "arm64")
r_release() works based on the SVN tags in the main R source code
repository. However, an SVN tag does not mean that the same version
is available for download. r_release_tarball returns the latest
version for which a source tarball is available.
r_release_tarball()r_release_tarball()
A one row data frame, with columns ‘version’, ‘date’, ‘URL’ and ‘nickname’.
This function is superseded by resolve():
r_release_tarball() #> # A data frame: 1 x 5 #> version date nickname semver URL #> <chr> <dttm> <chr> <pckg_vrs> <chr> #> 1 4.5.1 2025-06-13 07:12:01 Great Square Root 4.5.1 https://cran.rstudio~
resolve("release", platform = NA)
#> # A data frame: 1 x 6
#> version date nickname semver url type
#> <chr> <dttm> <chr> <pckg_vrs> <chr> <chr>
#> 1 4.5.1 2025-06-13 07:12:01 Great Square Root 4.5.1 https://cran.r~ rele~
Other R downloads:
r_release_macos(),
r_release_win()
r_release() r_release_tarball()r_release() r_release_tarball()
r_release() works based on the SVN tags in the main R source code
repository. However, an SVN tag does not mean that the same version
is available for download. r_release_win returns the latest
version for which a Windows installer is available.
r_release_win()r_release_win()
A one row data frame, with columns ‘version’, ‘date’, ‘URL’ and ‘nickname’.
This function is superseded by resolve():
r_release_win() #> # A data frame: 1 x 5 #> version date nickname semver URL #> <chr> <dttm> <chr> <pckg_vrs> <chr> #> 1 4.5.1 2025-06-13 07:12:01 Great Square Root 4.5.1 https://cran.rstudio~
resolve("release", platform = "windows")
#> # A data frame: 1 x 7
#> version date nickname semver url type rtools_url
#> <chr> <dttm> <chr> <pckg_vr> <chr> <chr> <chr>
#> 1 4.5.1 2025-06-13 07:12:01 Great Square Root 4.5.1 http~ rele~ https://g~
Other R downloads:
r_release_macos(),
r_release_tarball()
r_release() r_release_win()r_release() r_release_win()
R version numbers consist of three numbers (since version 1.4.1): major, minor and patch.
r_versions(dots = TRUE)r_versions(dots = TRUE)
dots |
Whether to use dots instead of dashes in the version number. |
We extract the version numbers from the tags in the SVN repository.
A data frame with three columns: ‘version’, ‘date’ and ‘nickname’.
r_versions()r_versions()
Resolve an R version specification
resolve(version = "release", platform = current_r_platform())resolve(version = "release", platform = current_r_platform())
version |
Symbolic version name to resolve. Possible values are
|
platform |
Operating system version. Defaults to
|
resolve() caches its results in the current R session. To clear the
cache restart R or set the R_VERSION_CACHE_TIMEOUT environment
variable to 0.
A one row data frame, with columns version, date,
nickname, semver, url, type, rtools_url (only for Windows).
resolve("release", "windows") resolve("4.4", "windows-aarch64") resolve("oldrel", "macos") resolve("devel", "linux-gnu-ubuntu-24.04") resolve("devel", "aarch64-unknown-linux-gnu-ubuntu-22.04")resolve("release", "windows") resolve("4.4", "windows-aarch64") resolve("oldrel", "macos") resolve("devel", "linux-gnu-ubuntu-24.04") resolve("devel", "aarch64-unknown-linux-gnu-ubuntu-22.04")
List Rtools versions
rtools_versions(arch = NULL)rtools_versions(arch = NULL)
arch |
Architecture. Possible values are:
|
A data frame with columns
version: The Rtools version, e.g. 45.
url: Download URL of the Rtools installer.
first: First R version supported by this Rtools version.
last: Last R version supported by this Rtools version.
rtools_versions() rtools_versions("aarch64")rtools_versions() rtools_versions("aarch64")